#--- This file repeats definitions made in proc InitialPreparations. This file can be used to change
#--- those definitions, because it is sourced in the proc after the initial definitions.
#--- workDir variable is defined in proc InitialPreparations.
#--- This file is required for the plotting procedures to work.

set dispColumn         Dispersion
set rmDerivFile        $workDir/ResponseMatrixDeriv.sdds
set rmDerivElementFile $workDir/ResponseMatrixDerivElem.sdds
set rmDerivInverseFile $workDir/ResponseMatrixDerivInverse.sdds
set rmDerivFileS       $rmDerivFile.S
set rmDerivFileV       $rmDerivFile.V
set rmDerivFileSV      $rmDerivFile.SV
set rmDerivFileU       $rmDerivFile.U
set rmDifferenceFile   $workDir/ResponseMatrixDifference.sdds
set dispersionFile     $workDir/dispersion.sdds
set hrmMeasured        $workDir/measuredhResponse.flhrm
set vrmMeasured        $workDir/measuredvResponse.flvrm
set hrmDifference      $workDir/RMhdifference.flhrm
set vrmDifference      $workDir/RMvdifference.flvrm
set hrmIterFile        $workDir/computed.flhrm
set vrmIterFile        $workDir/computed.flvrm
set elementsUpdateFile $workDir/elements_update.sdds
set noCorrectorsFile   $workDir/noElements.sdds
set weightFile         $workDir/weight.sdds
set manualWeightFile   $workDir/weightFile.sdds
set iterationsLogFile  $workDir/loco.log
set iterationsLogFileSDDS  $workDir/loco.log.sdds
set weightCorrectorsFile $workDir/weightCorrectors.sdds
set variableFile       $workDir/variables
set allElementsFile    $workDir/elements
set averageErrorFile   $workDir/avErrors.sdds
set nonlinFile         $workDir/bpmNonlin
set elementOrderFile   $workDir/orderOfElements.sdds
set dispMeasuredFile   $workDir/measuredDispersion.sdds
set sigmaWeightFileX   $workDir/sigmaWeightX.sdds
set sigmaWeightFileY   $workDir/sigmaWeightY.sdds
set specialElementsInputFile $workDir/specialElementsInput.sdds
set specialParamFile   $workDir/specialElements.sdds
set variableArchiveFile $workDir/elements.sdds.iterations


## Internal configuration setup for the LOCO fit:
#
## Corrector pattern has to end by * and has not to be very strict
## BPM pattern has to be very strict, only bpms should match (for dispersion file)!
## The calibration factors are for transformation from SRorbitResponse [mm/A] to elegant [m/rad]
## deltaKick is a change in correctors during measurements in Amp (total, if the change was positive and negative) 
## thetaKick is the deltaKick in rads
#
set verbose 0
#--- APS storage ring configuration:
set bRho 23.35

#--- Calibration related variables (1000*rad/A)
set hCalibFactor -0.82
set vCalibFactor -0.9
set dispCalibFactor 0.001
#--- Kick in fraction of full strength: 
set measurementKick 0.1
#--- Kick in rad ($[hv]CalibFactor * $measurementKick * 1e-3):
set thetaKickX 0.82e-4
set thetaKickY 0.9e-4

set dispFitWeight 30.0

#--- Rms of bpm reading in m/rad below which the bpm is declared a zero reading bpm
set zeroBpmTol 0.1

#--- kickRMD is the amplitude of the kick (rad) for RMD calculations. Should be 
#--- comparable or smaller than thetaKick
set kickRMD 1e-5

#--- Quad delta for RMD calculations (all 0.001 except for Tevatron where it is 1.0).
set rmdQuadDelta 0.0001
#--- Tilt delta form RMD calculations (1 if TEVATRON, 0.01 or less otherwise)
set rmdTiltDelta 0.0001

#--- SVD calculation related variables
#--- svdProgramName could be octave, matlab, sdds
set svdProgramName sdds
set matlabScriptDir  /home/oxygen/SAJAEV/LOCO/matlab

#--- Submitting Jobs related variables
set useQsubLong 1
set useQsubShort 1
set numberOfQsubTasksLong 8
set numberOfQsubTasksShort 4
set waitTimeLong 3600
set waitTimeShort 360
set waitIntervalLong 5
set waitIntervalShort 1
set submissionPauseLong 0
set submissionPauseShort 0

#--- variables for submitting on carnation without queue:
set qsubCommandShort "exec \$scriptFile &"
set queueSystemNameShort PS
set qsubRespProcCommandShort "lindex \$qsubResponse 0"

#--- weed.aps.anl.gov variables:
set qsubCommandLong  "exec \$scriptFile &"
set queueSystemNameLong PS
set qsubRespProcCommandLong "lindex \$qsubResponse 0"
#set qsubCommandLong  "exec qsub -cwd -V -j y -N \$jobName -e \$path/\$jobName.stderr -o \$path/\$jobName.stdout \$scriptFile"
#set queueSystemNameLong SGE
#set qsubRespProcCommandLong "lindex \$qsubResponse 2"
set remotePath ""

#--- Elegant response matrix calculation related variables
set directRMCalc 2
set fixedOrbitLength 1
#set elegantSkewMode quad
set useDoubleOrbits 1
set closedOrbit 1
set twissRefFile /home/oxygen/SAJAEV/APS/ERL-OPTICS/realRing.twi
set twissRefElement S1BEG
set malignElement MALIN

#--- Variables for nonlinear correction
set useIntercept 0
set useSlope 0
set useCubic 1

#--- This is used to find bad BPMs between outer loop iterations:
set badBpmSigmaLimit 5

#--- Variable for fully coupled analysis
set offDiagWeight 1
set makeSkewNamesUnique 1
set tiltCorFraction 1.0

#--- Variable for average BPM gain adjustment: can be average, dispersion, none.
set adjustAverageGains none

set useSigmaWeightFile 1

set useParallelMultiplication 0
set matrixDivisions 6

#--- OPTIM response matrix calculation related variables
set optimNonlin 1
set locoSearchString LOCOINSERT

set showMatchingMachineConfigOnly 1
set twiFile $workDir/booster.twi
  
#--- Variables for quad constraints:
set useQuadConstraints 2
set quadConstraintWeight 50
set quadConstraintFile dummy
set dontUsePrevQuadConstr 1

set convergenceTolerance 1e-6
set convergenceTolerance0 1e-5
set resErrorMax 5.0
